# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.knowledge_knowledge_entity_schemas_response import KnowledgeKnowledgeEntitySchemasResponse

class TestKnowledgeKnowledgeEntitySchemasResponse(unittest.TestCase):
    """KnowledgeKnowledgeEntitySchemasResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> KnowledgeKnowledgeEntitySchemasResponse:
        """Test KnowledgeKnowledgeEntitySchemasResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `KnowledgeKnowledgeEntitySchemasResponse`
        """
        model = KnowledgeKnowledgeEntitySchemasResponse()
        if include_optional:
            return KnowledgeKnowledgeEntitySchemasResponse(
                error = '',
                schemas = [
                    neurograph.v1.models.knowledge/knowledge_entity_schema_row.knowledge.KnowledgeEntitySchemaRow(
                        description = '', 
                        json_schema = neurograph.v1.models.json_schema.json_schema(), 
                        params_example = neurograph.v1.models.params_example.params_example(), 
                        schema_id = '', 
                        source_system = '', 
                        ts_created = 56, 
                        ts_updated = 56, )
                    ]
            )
        else:
            return KnowledgeKnowledgeEntitySchemasResponse(
        )
        """

    def testKnowledgeKnowledgeEntitySchemasResponse(self):
        """Test KnowledgeKnowledgeEntitySchemasResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
